@@ -13,6 +13,7 @@ from .cluster_processing.key_files_separator import KeyFilesSeparator
 from .cluster_processing.export_cluster_list import ExportClusterList
 from .training.cristal_structure_gen import CrystalStructureGenerator
 from .training.training_surface import HSM
+
 import os
 import json
 from .cluster_processing.cluster_macth import DumpProcessorFinger, StatisticsCalculatorFinger, JSONFeatureExporterFinger
@@ -37,4 +38,4 @@ from .training.training_graph import AtomicGraphGenerator
 from . runner.deformation_analyzer import DeformationAnalyzer
 from . runner.ws_predictor import WSMet
 from . predictors.coeff_vacancy import  GroupCoefficientCalculator
-from .predictors.vancy_network_keras import VacancyClassifierKeras,ModelConfig
\ No newline at end of file
+from .training.training_fingerstyle import FeatureExporter,DumpProcessor,StatisticsCalculator
\ No newline at end of file
