@@ -6,6 +6,7 @@ from pathlib import Path
 import os
 import pandas as pd
 import warnings
+import argparse
 warnings.filterwarnings('ignore', message='.*OVITO.*PyPI')
 
 def VacancyAnalysis():
@@ -34,6 +35,22 @@ def VacancyAnalysis():
         if configuracion['training']:
             gen = AtomicGraphGenerator()
             gen.run()
+            p = argparse.ArgumentParser(description="Exporta features (normas + ConvexHull) a CSV.")
+            p.add_argument("--output-csv", default="outputs/csv/finger_data.csv",
+                        help="Ruta del CSV de salida.")
+            p.add_argument("--dump", action="append",
+                        help="Ruta a uno o más .dump (repetible). Si se omite, se toma de input_params.json.")
+            args = p.parse_args()
+
+            exporter = FeatureExporter(
+                dump_paths=args.dump if args.dump else None,
+                output_csv=args.output_csv
+            )
+            try:
+                exporter.export()
+            except ImportError as e:
+                # Si falta SciPy, el compute_convex_hull lo avisa acá
+                print(f"[ERROR] {e}\nSugerencia: pip install scipy")
 
 
         analyzer = DeformationAnalyzer(FILE, configuracion['generate_relax'][0], configuracion['generate_relax'][5], threshold=0.02)
@@ -99,7 +116,6 @@ def VacancyAnalysis():
             surf_proc.export_results()
 
 
-
             exporter = ClusterFeatureExporter("outputs/json/key_archivos.json")
             exporter.export()
 
@@ -153,11 +169,7 @@ def VacancyAnalysis():
 
             #print(df_resultado[['archivo', 'grupo_predicho']])
 
-            df_key = pd.read_csv("outputs/csv/finger_key_files.csv")
-            df_cls = pd.read_csv("outputs/csv/defect_data.csv")
 
-            df_full = df_cls.merge(df_key, left_on="archivo", right_on="file_name", how="left")
-            df_full.to_csv("outputs/csv/finger_data_full_features.csv", index=False)
             #ETAPA DE PREDICCIONES
 
             trainer = VacancyModelTrainer(json_path="outputs/json/training_graph.json")
@@ -198,41 +210,7 @@ def VacancyAnalysis():
         )
         #print(out.head())
 
-
-
-
-        data_path = Path("outputs/json/training_graph.json")  # ajustá el path si corresponde
-        cfg = ModelConfig(artifacts_dir="artifacts_keras")
-
-        clf = VacancyClassifierKeras(cfg)
-        df = clf.load_json(data_path)
-
-        # 2) Preparar arrays
-        X, y = clf.prepare_arrays(df)
-
-        # 3) Split + escalado
-        X_train, X_val, X_test, y_train, y_val, y_test = clf.split_and_scale(X, y)
-
-        # 4) Construir y entrenar
-        clf.build_model(input_dim=X_train.shape[1])
-        clf.fit(X_train, y_train, X_val, y_val, verbose=1)
-
-        # 5) Evaluar
-        metrics = clf.evaluate(X_test, y_test)
-        print("\n== Métricas de test ==")
-        for k, v in metrics.items():
-            print(f"{k}: {v:.4f}")
-
-        # 6) Inferencia (ejemplo con la primera fila original del DataFrame)
-        #    OJO: acá usamos los valores NO escalados (la clase escala internamente).
-        sample = {k: float(df.iloc[0][k]) for k in clf.feature_order}
-        pred, probs = clf.predict_one(sample)
-        print(f"\nPredicción de vacancias (1..C): {pred}")
-        print("Probabilidades:", probs)
-        clf = VacancyClassifierKeras(ModelConfig(artifacts_dir="outputs/keras_artifacts"))
-        clf.load_artifacts(best=True)  # carga modelo + scaler + orden de features
-        clf.predict_csv("arcx.csv", "outputs/csv/arcx_predicho_keras.csv", return_probs=True)
-
+            
 
 if __name__ == "__main__":
     VacancyAnalysis()
